Subject: [PATCH] gnu: emacs-telega: Don't propagate ffmpeg.
From: Leo Prikler <[email-masked]>
To: [email-masked]
Date: Fri, 13 Dec 2019 14:05:24 +0100
List-Id: <debbugs-submit.debbugs.gnu.org>

* gnu/packages/emacs-xyz.scm (emacs-telega) [phases]:
<telega-data-patch>: Rename to telega-paths-patch.
<telega-paths-patch>: Substitute ffplay path.
[propagated-inputs] <ffmpeg>: Move from here ...
[inputs] <ffmpeg>: ... to here.
---
 gnu/packages/emacs-xyz.scm | 20 ++++++++++++++------
 1 file changed, 14 insertions(+), 6 deletions(-)

diff --git a/gnu/packages/emacs-xyz.scm b/gnu/packages/emacs-xyz.scm
index ae7e7a64cc..bc36b5dbce 100644
--- a/gnu/packages/emacs-xyz.scm
+++ b/gnu/packages/emacs-xyz.scm
@@ -20113,10 +20113,18 @@ fish-completion.  It can be used in both Eshell and M-x shell.")
                  (("python3 run_tests.py")
                   ""))
                #t))
-           ;; Modify telega-util to reflect unique dir name in
-           ;; `telega-install-data' phase.
-           (add-after 'unpack 'telega-data-patch
-             (lambda _
+           (add-after 'unpack 'telega-paths-patch
+             (lambda* (#:key inputs #:allow-other-keys)
+               ;; Hardcode `ffplay path.
+               (let ((ffplay-bin (string-append (assoc-ref inputs "ffmpeg")
+                                                "/bin/ffplay")))
+                 (substitute* "telega-ffplay.el"
+                   (("\\(executable-find \"ffplay\"\\)")
+                    (string-append
+                     "(and (file-executable-p \"" ffplay-bin "\")"
+                     "\"" ffplay-bin "\")"))))
+               ;; Modify telega-util to reflect unique dir name in
+               ;; `telega-install-data' phase.
                (substitute* "telega-util.el"
                  (("\\(concat \"etc/\" filename\\) telega--lib-directory")
                   "(concat \"telega-data/\" filename)
@@ -20149,7 +20157,6 @@ fish-completion.  It can be used in both Eshell and M-x shell.")
                (invoke "python3" "server/run_tests.py")
                #t))
            (delete 'configure)
-           
            ;; Build emacs-side using `emacs-build-system'
            (add-after 'compress-documentation 'emacs-add-source-to-load-path
              (assoc-ref emacs:%standard-phases 'add-source-to-load-path))
@@ -20168,9 +20175,10 @@ fish-completion.  It can be used in both Eshell and M-x shell.")
              (assoc-ref emacs:%standard-phases 'build))
            (add-after 'emacs-build 'emacs-make-autoloads
              (assoc-ref emacs:%standard-phases 'make-autoloads)))))
+      (inputs
+       `(("ffmpeg" ,ffmpeg))) ; mp4/gif support.
       (propagated-inputs
        `(("emacs-visual-fill-column" ,emacs-visual-fill-column)
-         ("ffmpeg" ,ffmpeg) ; mp4/gif support.
          ("libwebp" ,libwebp))) ; sticker support.
       (native-inputs
        `(("tdlib" ,tdlib)
-- 
2.24.1